==> onebapp-vue-dev-0.0.12.tgz: package/lib/backend/apollo.js <==
import { ApolloClient, createHttpLink, from, InMemoryCache } from '@apollo/client/core';
import { provideApolloClient as baseProvideApolloClient } from '@vue/apollo-composable';
import { request } from './request';
import { onError } from '@apollo/client/link/error';
import { handleError } from './index';
import { createBackendError as createBackendErrorFromRequest } from './request';
import { GraphqlError, ValidationError, InternalServerError } from './errors';
import { print } from 'graphql';
import { IS_DEV_ENV } from './config';
const createRequestInfo = (operation) => {
    const ctx = operation.getContext();
    return {
        id: ctx.response.headers.get('X-Request-Id') || '[empty]',
        method: ctx.response.requestMethod ?? '[unknown]',
        url: ctx.response.url,
        body: ctx.response.requestBody ?? '[unknown]'
    };
};
const createResponseInfo = (operation, body) => {
    const ctx = operation.getContext();
    return {
        status: ctx.response.status,
        body: ctx.response.errorBodyText ?? ctx.response.errorBodyJson ?? body ?? '[unknown]'
    };
};
const errorLink = onError(({ graphQLErrors, networkError, operation, response }) => {
    // console.log(operation.getContext().response, response)
    const error = networkError
        ? createBackendErrorFromRequest(networkError)
        : new GraphqlError(createRequestInfo(operation), createResponseInfo(operation, response));
    const validation = graphQLErrors?.filter((i) => i.extensions.category === 'validation') ?? [];
    const internal = graphQLErrors?.filter((i) => i.extensions.category === 'internal') ?? [];
    let finalError = error;
    if (internal.length > 0) {
        finalError = new InternalServerError(error.request, error.response, 'Graphql: ' + internal.map((i) => `${i.message}`).join('; '));
    }
    else if (validation.length > 0) {
        finalError = new ValidationError(validation.reduce(
        // @ts-ignore
        (acc, item) => ({ ...acc, ...item.extensions.validation }), {}), error.message, error.request, error.response);
    }
    finalError.addTag('graphql', {
        operation: operation.operationName,
        query: print(operation.query),
        variables: operation.variables,
        extensions: operation.extensions,
        errors: response?.errors === graphQLErrors ? '[response.body.errors]' : graphQLErrors
    });
    handleError(finalError);
});
// HTTP connection to the API
const httpLink = createHttpLink({
    uri: `graphql`,
    fetch: request
});
// Cache implementation
const cache = new InMemoryCache();
export const apollo = new ApolloClient({
    link: from([errorLink, httpLink]),
    cache,
    connectToDevTools: IS_DEV_ENV
});
export const clearApolloCache = () => cache.reset();
export const provideApolloClient = () => {
    baseProvideApolloClient(apollo);
};

==> onebapp-vue-dev-0.0.14.tgz: package/lib/backend/apollo.js <==
import { ApolloClient, createHttpLink, from, InMemoryCache } from '@apollo/client/core';
import { provideApolloClient as baseProvideApolloClient } from '@vue/apollo-composable';
import { request } from './request';
import { onError } from '@apollo/client/link/error';
import { handleError } from './index';
import { createBackendError as createBackendErrorFromRequest } from './request';
import { GraphqlError, ValidationError, InternalServerError } from './errors';
import { print } from 'graphql';
import { GRAPHQL_URL, IS_DEV_ENV } from './config';
const createRequestInfo = (operation) => {
    const ctx = operation.getContext();
    return {
        id: ctx.response.headers.get('X-Request-Id') || '[empty]',
        method: ctx.response.requestMethod ?? '[unknown]',
        url: ctx.response.url,
        body: ctx.response.requestBody ?? '[unknown]'
    };
};
const createResponseInfo = (operation, body) => {
    const ctx = operation.getContext();
    return {
        status: ctx.response.status,
        body: ctx.response.errorBodyText ?? ctx.response.errorBodyJson ?? body ?? '[unknown]'
    };
};
const errorLink = onError(({ graphQLErrors, networkError, operation, response }) => {
    const error = networkError
        ? createBackendErrorFromRequest(networkError)
        : new GraphqlError(createRequestInfo(operation), createResponseInfo(operation, response));
    const validation = graphQLErrors instanceof Array ? graphQLErrors.filter((i) => i.extensions.category === 'validation') ?? [] : [];
    const internal = graphQLErrors instanceof Array ? graphQLErrors.filter((i) => i.extensions.category === 'internal') ?? [] : [];
    let finalError = error;
    if (internal.length > 0) {
        finalError = new InternalServerError(error.request, error.response, 'Graphql: ' + internal.map((i) => `${i.message}`).join('; '));
    }
    else if (validation.length > 0) {
        finalError = new ValidationError(validation.reduce(
        // @ts-ignore
        (acc, item) => ({ ...acc, ...item.extensions.validation }), {}), error.message, error.request, error.response);
    }
    finalError.addTag('graphql', {
        operation: operation.operationName,
        query: print(operation.query),
        variables: operation.variables,
        extensions: operation.extensions,
        errors: response?.errors === graphQLErrors ? '[response.body.errors]' : graphQLErrors
    });
    handleError(finalError);
});
// HTTP connection to the API
const httpLink = createHttpLink({
    uri: GRAPHQL_URL,
    fetch: request
});
// Cache implementation
const cache = new InMemoryCache();
export const apollo = new ApolloClient({
    link: from([errorLink, httpLink]),
    cache,
    connectToDevTools: IS_DEV_ENV
});
export const clearApolloCache = () => cache.reset();
export const provideApolloClient = () => {
    baseProvideApolloClient(apollo);
};
